==> pythresh-0.2.9.tar.gz: pythresh-0.2.9/setup.py <==
import re
import sys
from io import open
# read the contents of README file
from os import path

from setuptools import find_packages, setup

# get __version__ from version.py
try:
    verpath = path.join('pythresh', 'version.py')
    with open(verpath) as version_file:
        __version__ = str(re.findall(
            r'\b\d+(?:\.\d+)+', version_file.read())[0])
except Exception as error:
    __version__ = "0.0.1"
    sys.stderr.write("Warning: Could not open '%s' due %s\n" %
                     (verpath, error))


this_directory = path.abspath(path.dirname(__file__))


# read the contents of README.rst
def readme():
    with open(path.join(this_directory, 'README.rst'), encoding='utf-8') as f:
        return f.read()


# read the contents of requirements.txt
with open(path.join(this_directory, 'requirements.txt'),
          encoding='utf-8') as f:
    requirements = f.read().splitlines()

setup(
    name='pythresh',
    version=__version__,
    description='A Python Toolbox for Outlier Detection Thresholding',
    long_description=readme(),
    long_description_content_type='text/x-rst',
    author='D Kulik',
    url='https://github.com/KulikDM/pythresh',
    download_url='https://github.com/KulikDM/pythresh/archive/master.zip',
    keywords=['outlier detection', 'anomaly detection', 'thresholding', 'cutoff',
              'contamintion level', 'data science', 'machine learning'],
    project_urls={
        "Documentation": 'https://pythresh.readthedocs.io/en/latest/'},
    packages=find_packages(exclude=['test']),
    include_package_data=True,
    install_requires=requirements,
    setup_requires=['setuptools>=38.6.0'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Education',
        'Intended Audience :: Financial and Insurance Industry',
        'Intended Audience :: Science/Research',
        'Intended Audience :: Developers',
        'Intended Audience :: Information Technology',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
    ],
)

==> pythresh-0.3.1.tar.gz: pythresh-0.3.1/setup.py <==
import re
import sys
# read the contents of README file
from os import path

from setuptools import find_packages, setup

# get __version__ from version.py
try:
    verpath = path.join('pythresh', 'version.py')
    with open(verpath) as version_file:
        __version__ = str(re.findall(
            r'\b\d+(?:\.\d+)+', version_file.read())[0])
except Exception as error:
    __version__ = '0.0.1'
    sys.stderr.write("Warning: Could not open '%s' due %s\n" %
                     (verpath, error))


this_directory = path.abspath(path.dirname(__file__))


# read the contents of README.rst
def readme():
    with open(path.join(this_directory, 'README.rst'), encoding='utf-8') as f:
        return f.read()


# read the contents of requirements.txt
with open(path.join(this_directory, 'requirements.txt'),
          encoding='utf-8') as f:
    requirements = f.read().splitlines()

setup(
    name='pythresh',
    version=__version__,
    description='A Python Toolbox for Outlier Detection Thresholding',
    long_description=readme(),
    long_description_content_type='text/x-rst',
    author='D Kulik',
    url='https://github.com/KulikDM/pythresh',
    download_url='https://github.com/KulikDM/pythresh/archive/master.zip',
    keywords=['outlier detection', 'anomaly detection', 'thresholding', 'cutoff',
              'contamintion level', 'data science', 'machine learning'],
    project_urls={
        'Documentation': 'https://pythresh.readthedocs.io/en/latest/'},
    packages=find_packages(exclude=['test']),
    include_package_data=True,
    install_requires=requirements,
    setup_requires=['setuptools>=38.6.0'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Education',
        'Intended Audience :: Financial and Insurance Industry',
        'Intended Audience :: Science/Research',
        'Intended Audience :: Developers',
        'Intended Audience :: Information Technology',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
    ],
)
